%This script demonstrates how to change the network configuration.
%This changes the static IP address to the new value, and then 
%switches to static mode if it is not already.  It will then attempt
%to reconnect to the new address.

address = '10.0.41.2';

newStaticAddress = '10.0.41.3';
newStaticMask = '255.255.0.0';
newStaticGateway = '10.0.0.1';

hyperionInstrument = hCOMMOpenConnection(address, 'commandPort', 1);

serialNumber = hSYSTEMGetSerialNumber(hyperionInstrument);
currentNetworkMode = hNETGetNetworkIPMode(hyperionInstrument);

[currentStaticAddress, currentStaticMask, currentStaticGateway] = ...
    hNETGetStaticNetworkSettings(hyperionInstrument);

[currentAddress, currentMask, currentGateway] = hNETGetActiveNetworkSettings(hyperionInstrument);
    
    

disp(['Instrument Serial Number:  ', serialNumber]);
disp(['Current Network Mode:  ', currentNetworkMode]);

switch currentNetworkMode
    case 'STATIC'
        
        disp('Changing to new static network settings.')
        disp('This will cause the current network connection to close.')
        hNETSetStaticNetworkSettings(hyperionInstrument, newStaticAddress, newStaticMask, newStaticGateway);
        hCOMMCloseConnection(hyperionInstrument)
        
        disp(['Reconnecting to new static address: ', newStaticAddress])
        
        pause(5);
        
        hyperionInstrument = hCOMMOpenConnection(newStaticAddress, 'commandPort', 1);
        serialNumber = hSYSTEMGetSerialNumber(hyperionInstrument);

        disp(['Connected.  Instrument serial number:  ', serialNumber]);
        
    case 'DHCP'
        disp('Changing the static network settings')
        hNETSetStaticNetworkSettings(hyperionInstrument, newStaticAddress, newStaticMask, newStaticGateway);
        disp('Changing to Static mode.  This will cause the current network connection to close.')
        hNETSetNetworkIPMode(hyperionInstrument, 'STATIC');
        hCOMMCloseConnection(hyperionInstrument);
        
        disp(['Reconnecting to new static address: ', newStaticAddress])
        
        pause(5);
        
        hyperionInstrument = hCOMMOpenConnection(newStaticAddress, 'commandPort', 1);
        serialNumber = hSYSTEMGetSerialNumber(hyperionInstrument);

        disp(['Connected.  Instrument serial number:  ', serialNumber]);
end

disp('Closing connection')

hCOMMCloseConnection(hyperionInstrument);

